==> haskell-uglymemo-0.1.0.1-14-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-uglymemo.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 uglymemo
version:              0.1.0.1
visibility:           public
id:                   uglymemo-0.1.0.1-DFD8u6eNJY85JNumvVVja9
key:                  uglymemo-0.1.0.1-DFD8u6eNJY85JNumvVVja9
license:              LicenseRef-PublicDomain
maintainer:           lennart@augustsson.net
author:               Lennart Augustsson
synopsis:             A simple (but internally ugly) memoization function.
description:
    A simple (but internally ugly) memoization function.

    * New in 0.1.0.1: Make it exception safe.

category:             Data
abi:                  0a495e8ac4f91363866156fb4adb3673
exposed:              True
exposed-modules:      Data.MemoUgly
import-dirs:          /usr/lib/ghc-8.8.3/site-local/uglymemo-0.1.0.1
library-dirs:         /usr/lib/ghc-8.8.3/site-local/uglymemo-0.1.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.8.3/uglymemo-0.1.0.1
hs-libraries:         HSuglymemo-0.1.0.1-DFD8u6eNJY85JNumvVVja9
depends:              base-4.13.0.0 containers-0.6.2.1
haddock-interfaces:   /usr/share/doc/haskell-uglymemo/html/uglymemo.haddock
haddock-html:         /usr/share/doc/haskell-uglymemo/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-uglymemo-0.1.0.1-15-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-uglymemo.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 uglymemo
version:              0.1.0.1
visibility:           public
id:                   uglymemo-0.1.0.1-DsrHcnYNurj4qkvghV67BN
key:                  uglymemo-0.1.0.1-DsrHcnYNurj4qkvghV67BN
license:              LicenseRef-PublicDomain
maintainer:           lennart@augustsson.net
author:               Lennart Augustsson
synopsis:             A simple (but internally ugly) memoization function.
description:
    A simple (but internally ugly) memoization function.

    * New in 0.1.0.1: Make it exception safe.

category:             Data
abi:                  ea240b91d94b44cabeadd344b982fbaa
exposed:              True
exposed-modules:      Data.MemoUgly
import-dirs:          /usr/lib/ghc-8.10.1/site-local/uglymemo-0.1.0.1
library-dirs:         /usr/lib/ghc-8.10.1/site-local/uglymemo-0.1.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.1/uglymemo-0.1.0.1
hs-libraries:         HSuglymemo-0.1.0.1-DsrHcnYNurj4qkvghV67BN
depends:              base-4.14.0.0 containers-0.6.2.1
haddock-interfaces:   /usr/share/doc/haskell-uglymemo/html/uglymemo.haddock
haddock-html:         /usr/share/doc/haskell-uglymemo/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
